searchData={"items":[{"type":"module","title":"SilverOrb","doc":"Documentation for `SilverOrb`.","ref":"SilverOrb.html"},{"type":"function","title":"SilverOrb.hello/0","doc":"Hello world.","ref":"SilverOrb.html#hello/0"},{"type":"function","title":"Examples - SilverOrb.hello/0","doc":"iex> SilverOrb.hello()\n    :world","ref":"SilverOrb.html#hello/0-examples"},{"type":"module","title":"SilverOrb.Arena","doc":"Arena allocation.\n\nSee https://www.rfleury.com/p/untangling-lifetimes-the-arena-allocator\n\n```elixir\ndefmodule ArenaExample do\n  SilverOrb.Arena.def(First, pages: 2)\n  SilverOrb.Arena.def(Second, pages: 4, max_pages: 10)\n\n  defw example(), a: I32.UnsafePointer, b: I32.UnsafePointer do\n    a = First.alloc(4)\n    Memory.store!(I32, a, 42)\n\n    b = Second.alloc(4)\n    Memory.store!(I32, b, 99)\n\n    assert!(a !== First.alloc(4))\n    First.rewind()\n    assert!(a === First.alloc(4))\n  end\nend\n```","ref":"SilverOrb.Arena.html"},{"type":"macro","title":"SilverOrb.Arena.def/2","doc":"Defines an arena of memory. An Elixir module with your passed `name` is defined with `alloc!/1` and `rewind/0` functions.","ref":"SilverOrb.Arena.html#def/2"},{"type":"macro","title":"Options - SilverOrb.Arena.def/2","doc":"When defining an arena, two options can be given:\n\n- `:pages` — The number of pages to allocate for this arena. The global memory is increased by this count.\n- `:max_pages` — The maxmimum number of pages this can increase the global memory by using `Orb.Memory.grow!/1`. Only the last arena can support `max_pages`, as otherwise multiple arenas each growing in size will end up overlapping.","ref":"SilverOrb.Arena.html#def/2-options"},{"type":"function","title":"SilverOrb.Arena.funcp/0","doc":"Import all WebAssembly functions from this module’s Orb definition.","ref":"SilverOrb.Arena.html#funcp/0"},{"type":"function","title":"SilverOrb.Arena.funcp/1","doc":"Import a specific WebAssembly function from this module’s Orb definition.","ref":"SilverOrb.Arena.html#funcp/1"},{"type":"function","title":"SilverOrb.Arena.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.Arena.html#to_wat/0"},{"type":"module","title":"SilverOrb.BumpAllocator","doc":"A bump allocator for Orb modules.\n\n```elixir\ndefmodule Example do\n  use Orb\n  use SilverOrb.BumpAllocator\n\nend\n```","ref":"SilverOrb.BumpAllocator.html"},{"type":"function","title":"SilverOrb.BumpAllocator.alloc/1","doc":"","ref":"SilverOrb.BumpAllocator.html#alloc/1"},{"type":"macro","title":"SilverOrb.BumpAllocator.export_alloc/0","doc":"","ref":"SilverOrb.BumpAllocator.html#export_alloc/0"},{"type":"function","title":"SilverOrb.BumpAllocator.funcp/0","doc":"Import all WebAssembly functions from this module’s Orb definition.","ref":"SilverOrb.BumpAllocator.html#funcp/0"},{"type":"function","title":"SilverOrb.BumpAllocator.funcp/1","doc":"Import a specific WebAssembly function from this module’s Orb definition.","ref":"SilverOrb.BumpAllocator.html#funcp/1"},{"type":"function","title":"SilverOrb.BumpAllocator.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.BumpAllocator.html#to_wat/0"},{"type":"module","title":"SilverOrb.BumpAllocator.Constants","doc":"","ref":"SilverOrb.BumpAllocator.Constants.html"},{"type":"function","title":"SilverOrb.BumpAllocator.Constants.bump_init_offset/0","doc":"","ref":"SilverOrb.BumpAllocator.Constants.html#bump_init_offset/0"},{"type":"module","title":"SilverOrb.Mem","doc":"memcpy and memset for Orb.\n\n```elixir\ndefmodule Example do\n  use Orb\n  use SilverOrb.Mem\n\nend\n```","ref":"SilverOrb.Mem.html"},{"type":"function","title":"SilverOrb.Mem.funcp/0","doc":"Import all WebAssembly functions from this module’s Orb definition.","ref":"SilverOrb.Mem.html#funcp/0"},{"type":"function","title":"SilverOrb.Mem.funcp/1","doc":"Import a specific WebAssembly function from this module’s Orb definition.","ref":"SilverOrb.Mem.html#funcp/1"},{"type":"function","title":"SilverOrb.Mem.memcpy/1","doc":"","ref":"SilverOrb.Mem.html#memcpy/1"},{"type":"function","title":"SilverOrb.Mem.memcpy/3","doc":"","ref":"SilverOrb.Mem.html#memcpy/3"},{"type":"function","title":"SilverOrb.Mem.memset/1","doc":"","ref":"SilverOrb.Mem.html#memset/1"},{"type":"function","title":"SilverOrb.Mem.to_wat/0","doc":"Convert this module’s Orb definition to WebAssembly text (Wat) format.","ref":"SilverOrb.Mem.html#to_wat/0"},{"type":"extras","title":"SilverOrb","doc":"# SilverOrb\n\nA standard library for Orb.\n\nThe docs can be found at  .\n\n- Arena allocator\n- Memory copying and setting\n- Coming: String builder\n- Coming: ASCII functions\n- Coming: UTF8 functions\n- Coming: Integer formatting\n- Coming: Date formatting","ref":"readme.html"},{"type":"extras","title":"Installation - SilverOrb","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `silver_orb` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:silver_orb, \"~> 0.0.5\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown"}